@@ -179,6 +179,12 @@ class MoveLine(ModelSQL, ModelView):
     @classmethod
     def __setup__(cls):
         super(MoveLine, cls).__setup__()
+        cls._buttons.update({
+            'apply_analytic_rules': {
+                'invisible': Eval('analytic_state') != 'draft',
+                'depends': ['analytic_state'],
+                },
+            })
         cls._check_modify_exclude |= {'analytic_lines', 'analytic_state'}
 
     @classmethod
@@ -212,8 +218,14 @@ class MoveLine(ModelSQL, ModelView):
     @property
     def must_have_analytic(self):
         "If the line must have analytic lines set"
+        pool = Pool()
+        FiscalYear = pool.get('account.fiscalyear')
         if self.account.type:
-            return self.account.type.statement == 'income'
+            return self.account.type.statement == 'income' and not (
+                # ignore balance move of non-deferral account
+                self.journal.type == 'situation'
+                and self.period.type == 'adjustment'
+                and isinstance(self.move.origin, FiscalYear))
 
     @classmethod
     def apply_rule(cls, lines):
@@ -271,6 +283,13 @@ class MoveLine(ModelSQL, ModelView):
             else:
                 line.analytic_state = 'valid'
 
+    @classmethod
+    @ModelView.button
+    def apply_analytic_rules(cls, lines):
+        cls.apply_rule(lines)
+        cls.set_analytic_state(lines)
+        cls.save(lines)
+
 
 class OpenAccount(Wizard):
     'Open Account'
@@ -280,7 +299,7 @@ class OpenAccount(Wizard):
 
     def do_open_(self, action):
         action['pyson_domain'] = [
-            ('account', '=', Transaction().context['active_id']),
+            ('account', '=', self.record.id if self.record else None),
             ]
         if Transaction().context.get('start_date'):
             action['pyson_domain'].append(
@@ -290,6 +309,8 @@ class OpenAccount(Wizard):
             action['pyson_domain'].append(
                 ('date', '<=', Transaction().context['end_date'])
                 )
+        if self.record:
+            action['name'] += ' (%s)' % self.record.rec_name
         action['pyson_domain'] = PYSONEncoder().encode(action['pyson_domain'])
         return action, {}
 
